==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-compat/src/main/java/org/apache/maven/repository/legacy/WagonConfigurationException.java <==
package org.apache.maven.repository.legacy;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.wagon.TransferFailedException;

/**
 * WagonConfigurationException
 */
public class WagonConfigurationException
    extends TransferFailedException
{

    static final long serialVersionUID = 1;

    private final String originalMessage;
    private final String repositoryId;

    public WagonConfigurationException( String repositoryId,
                                        String message,
                                        Throwable cause )
    {
        super( "While configuring wagon for \'" + repositoryId + "\': " + message, cause );

        this.repositoryId = repositoryId;
        this.originalMessage = message;
    }

    public WagonConfigurationException( String repositoryId,
                                        String message )
    {
        super( "While configuring wagon for \'" + repositoryId + "\': " + message );

        this.repositoryId = repositoryId;
        this.originalMessage = message;
    }

    public final String getRepositoryId()
    {
        return repositoryId;
    }

    public final String getOriginalMessage()
    {
        return originalMessage;
    }

}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-compat/src/main/java/org/apache/maven/repository/legacy/WagonConfigurationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.repository.legacy;

import org.apache.maven.wagon.TransferFailedException;

/**
 * WagonConfigurationException
 */
public class WagonConfigurationException extends TransferFailedException {

    static final long serialVersionUID = 1;

    private final String originalMessage;
    private final String repositoryId;

    public WagonConfigurationException(String repositoryId, String message, Throwable cause) {
        super("While configuring wagon for \'" + repositoryId + "\': " + message, cause);

        this.repositoryId = repositoryId;
        this.originalMessage = message;
    }

    public WagonConfigurationException(String repositoryId, String message) {
        super("While configuring wagon for \'" + repositoryId + "\': " + message);

        this.repositoryId = repositoryId;
        this.originalMessage = message;
    }

    public final String getRepositoryId() {
        return repositoryId;
    }

    public final String getOriginalMessage() {
        return originalMessage;
    }
}
